==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-react-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-react-core";
/**
 * @hidden
 */
export let CustomIndicator = /*@__PURE__*/ (() => {
    class CustomIndicator extends StrategyBasedIndicator {
        constructor() {
            super(...arguments);
            this.u3 = null;
            this.u2 = null;
        }
        get_uh() {
            return new CustomIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return CustomIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        tt(a, b) {
            let c = this.qp(a, b);
            let d = this.qq(c);
            let e = new List$1(String_$type, 0);
            if (this.basedOnColumns != null) {
                let f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
                this.basedOnColumns(this, f);
                if (f.basedOn != null) {
                    for (let g of fromEnum(f.basedOn)) {
                        e.add(g);
                    }
                }
            }
            return e;
        }
        get indicator() {
            return this.u3;
        }
        set indicator(a) {
            this.u3 = a;
            this.t1();
        }
        get basedOnColumns() {
            return this.u2;
        }
        set basedOnColumns(a) {
            this.u2 = a;
        }
        tq(a, b) {
            super.tq(a, b);
            if (this.indicator != null) {
                let c = this.qp(a, b);
                if (b == 0) {
                    return false;
                }
                if (!this.rl(this.tt(a, b))) {
                    return false;
                }
                this.indicator(this, new FinancialEventArgs(a, b, c, this.qq(c), this));
                if (this.uj(c) && this.qy != null) {
                    this.qy.c0();
                }
                return true;
            }
            return false;
        }
    }
    CustomIndicator.$t = /*@__PURE__*/ markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
})();

==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-react-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-react-core";
/**
 * @hidden
 */
export let CustomIndicator = /*@__PURE__*/ (() => {
    class CustomIndicator extends StrategyBasedIndicator {
        constructor() {
            super(...arguments);
            this.u7 = null;
            this.u6 = null;
        }
        get_ul() {
            return new CustomIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return CustomIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        tx(a, b) {
            let c = this.qt(a, b);
            let d = this.qu(c);
            let e = new List$1(String_$type, 0);
            if (this.basedOnColumns != null) {
                let f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
                this.basedOnColumns(this, f);
                if (f.basedOn != null) {
                    for (let g of fromEnum(f.basedOn)) {
                        e.add(g);
                    }
                }
            }
            return e;
        }
        get indicator() {
            return this.u7;
        }
        set indicator(a) {
            this.u7 = a;
            this.t5();
        }
        get basedOnColumns() {
            return this.u6;
        }
        set basedOnColumns(a) {
            this.u6 = a;
        }
        tu(a, b) {
            super.tu(a, b);
            if (this.indicator != null) {
                let c = this.qt(a, b);
                if (b == 0) {
                    return false;
                }
                if (!this.rp(this.tx(a, b))) {
                    return false;
                }
                this.indicator(this, new FinancialEventArgs(a, b, c, this.qu(c), this));
                if (this.un(c) && this.q2 != null) {
                    this.q2.c0();
                }
                return true;
            }
            return false;
        }
    }
    CustomIndicator.$t = /*@__PURE__*/ markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
})();
